/*******************************************************************************
* Copyright (c) 2007, Perforce Software, Inc.  All rights reserved.
* 
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
* 
* 1.  Redistributions of source code must retain the above copyright
*     notice, this list of conditions and the following disclaimer.
* 
* 2.  Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the
*     documentation and/or other materials provided with the distribution.
* 
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE 
* SOFTWARE, INC. BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
* ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR 
* TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
* THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
* DAMAGE.
*******************************************************************************/

#include <stdhdrs.h>
#include <strbuf.h>
#include <vararray.h>
#include "cmdline.h"

CmdLine::CmdLine()
{
    hasName = 0;
}

CmdLine::CmdLine( const StrPtr &procName )
{
    StrBuf *t = (StrBuf *) argv.Put( new StrBuf );
    t->Set( procName );
    hasName = 1;
}

CmdLine::~CmdLine()
{
    for( int i = 0; i < argv.Count(); i++ )
	delete (StrBuf *) argv.Get( i );
}

//
// Add an argument to the command line
//
void
CmdLine::Arg( const char *arg )
{
    if( strlen( arg ) > 0 )
    {
        StrBuf *t = (StrBuf *) argv.Put( new StrBuf );
        t->Set( arg );
    }
}

//
// Return the command line args ready for exec()
//
char *const *
CmdLine::Argv()
{
    char **	av = new char *[ argv.Count() + 1 ];
    int		i = 0;

    for( i = 0; i < argv.Count(); i++ )
	av[ i ] = ((StrBuf *)argv.Get( i ))->Text();

    av[ i ] = 0;
    return av;
}

void
CmdLine::Fmt( const char *cmd, StrBuf &buf )
{
    int	space = 0;

    buf << cmd;
    for( int i = hasName; i < argv.Count(); i++ )
    {
	buf << " ";
	buf.Append( (StrBuf *) argv.Get( i ) );
    }
}

